from django.forms import (CharField, HiddenInput, IntegerField, ModelForm,
                          NumberInput, Textarea, ValidationError)

from core.models import Feedback


#<textarea cols="40" id="id_text" name="text" rows="10" required=""></textarea>
#<input id="id_score" min="0" name="score" type="number" value="0" required="">
#form-control

class FeedbackForm(ModelForm):
    text = CharField(
        widget=Textarea(
            attrs={
                'name': 'text',
                'id': 'id_text',
                'novalidate': '',
                'autofocus': ''
            }
        ),
        label='',
        required=False,
    )

    score = IntegerField(
        widget=NumberInput(
            attrs={
                'name': 'score',
                'id': 'id_score',
                'min': '0',
                'class': 'form-control mx-sm-1',
            }
        )
    )

    def clean(self):
        cleaned_data = super().clean()
        score = cleaned_data.get("score")
        full_score = self.instance.of_submission.type.full_score

        if not score <= full_score:
            raise ValidationError(
                "Score too high. Maximium score is %(max_score)d",
                code='over_max_score',
                params={'max_score': full_score},
            )

    class Meta:
        model = Feedback
        auto_id = False
        fields = ('text', 'score', 'of_submission', 'of_tutor')
        widgets = {
            'of_submission': HiddenInput,
            'of_tutor': HiddenInput,
        }
